# eric7.Plugins.UiExtensionPlugins.Translator.TranslatorEngines

Package containing the various translation engines.

### Modules

DeepLEngine | Module implementing the DeepL translation engine.
GoogleV1Engine | Module implementing the Google V1 translation engine.
GoogleV2Engine | Module implementing the Google V2 translation engine.
IbmWatsonEngine | Module implementing the IBM Watson translation engine.
MicrosoftEngine | Module implementing the Microsoft translation engine.
MyMemoryEngine | Module implementing the MyMemory translation engine.
TranslationEngine | Module implementing the translation engine base class.
YandexEngine | Module implementing the Yandex translation engine.
TranslatorEngines | Package containing the various translation engines.